#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
# Copyright 2022 Stéphane Caron
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .test_clone_to_cache import TestCloneToCache
from .test_clone_to_directory import TestCloneToDirectory
from .test_descriptions import TestDescriptions
from .test_loaders import TestLoaders
from .test_progress_bar import TestProgressBar

__all__ = [
    "TestCloneToCache",
    "TestCloneToDirectory",
    "TestDescriptions",
    "TestLoaders",
    "TestProgressBar",
]
